#!/bin/sh
#
# mkfsimage - Create a filesystem image
#
# Copyright (c) 2008, TeamF1, Inc.
#
# modification history
# --------------------
# 01a,29oct08,suh created
#
#

# Filesystem type
fsType=$1
# Root of filesystem
fsRootDir=$2
# Image name
fsImage=$3
# Image size 
fsSize=$4
# Mount point to use while creating the image
mntDir=$5

warn()
  {
  echo "WARNING: " $@
  }

error()
  {
  echo '*** ['$(basename 0)'] ERROR: ' $@
  [ ! -z $(losetup ${loopDevice} 2>/dev/null) ] && losetup -d ${loopDevice}
  exit -1
  }

main()
  {
  loopDevice=$(losetup -f)
  [ -z ${loopDevice} ] && error "Couldn't find a free loop device"

  dd if="/dev/zero" of="${fsImage}" bs=${fsSize} count=1
  [ $? -ne 0 ] && error "Couldn't create rootfs image file ${fsImage}"

  losetup ${loopDevice} ${fsImage}
  [ $? -ne 0 ] && error "Couldn't setcreate rootfs image file ${fsImage}"

  mkfs -t ${fsType}  ${loopDevice}
  [ $? -ne 0 ] && error "Couldn't create ${fsType} filesystem image on device ${loopDevice}"

  mount -t ${fsType} ${loopDevice} ${mntDir}
  [ $? -ne 0 ] && error "Couldn't mount ${loopDevice} at ${mntDir}"

  cp -a  ${fsRootDir}/* ${mntDir}/

  umount ${mntDir}
  [ $? -ne 0 ] && warn "Couldn't umount ${loopDevice} from ${mntDir}"

  losetup -d ${loopDevice}
  [ $? -ne 0 ] && error "Couldn't detach ${loopDevice}"

  echo "Created rootfs image ${fsImage}"
  }


main
