/* Shared library add-on to iptables for the ANTISPOOF target
 * (C) 2000 by Harald Welte <laforge@gnumonks.org>
 *
 * $Id: libipt_ANTISPOOF.c,v 1.3 2006/02/25 16:12:03 nprasad Exp $
 *
 * This program is distributed under the terms of GNU GPL
 */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <getopt.h>
#include <iptables.h>

#include <linux/netfilter_ipv4/ip_tables.h>
#include <linux/netfilter_ipv4/ipt_ANTISPOOF.h>

static void init(struct ipt_entry_target *t, unsigned int *nfcache) 
{
}

static void help(void) 
{
 printf ("ANTISPOOF target Command is of the form\n"
                     "iptables -t filter -I INPUT  -j ANTISPOOF --log-enable 1 or 0\n");
}
    static void
parse_antispoof(const char *s, struct ipt_antispoof_target_info *info)
    {
    unsigned int i, logStatus;
    if (string_to_number(s, 0, 255, &logStatus) != -1) {
        if (logStatus == IPANTISPOOF_LOG_ENABLE
            || logStatus == IPANTISPOOF_LOG_DISABLE) {
            info->logStatus = (u_int8_t )logStatus;
            return;
        }
    } else {
                info->logStatus = IPANTISPOOF_LOG_DISABLE;
                return;
    }
    exit_error(PARAMETER_PROBLEM, "Bad log Status  value `%s'", s);
    }

static int parse(int c, char **argv, int invert, unsigned int *flags,
		const struct ipt_entry *entry,
		struct ipt_entry_target **target)
    {
    struct ipt_antispoof_target_info *antispoofinfo
        = (struct ipt_antispoof_target_info *)(*target)->data;

    switch (c) {
        case '1':
        if (*flags)
            exit_error(PARAMETER_PROBLEM,
                       "TOS target: Cant specify --log-enable  twice");
        parse_antispoof(optarg, antispoofinfo);
        *flags = 1;
        break;

        default:
        return 0;
    }

    return 1;

    }

static void final_check(unsigned int flags)
    {
    if (!flags)
        fprintf (stderr, "ANTI SPOOF : Parameter --log-enable 0/1 is required "
                 "has parameters.\n");

    }

static void save(const struct ipt_ip *ip,
		const struct ipt_entry_target *target)
{
    const struct ipt_antispoof_target_info *antispoofinfo =
        (const struct ipt_antispoof_target_info *)target->data;
    printf("--log-enable %d ", antispoofinfo->logStatus);
}

static void print(const struct ipt_ip *ip,
		const struct ipt_entry_target *target, int numeric)
  {
    const struct ipt_antispoof_target_info *antispoofinfo =
        (const struct ipt_antispoof_target_info *)target->data;
    printf("log-enable ");
    printf("%d ", antispoofinfo->logStatus);

  }

static struct option opts[] = {
        { "log-enable", 1, 0, '1' },
            { 0 }
};


static struct iptables_target ANTISPOOF = {
	.next		= NULL, 
	.name		= "ANTISPOOF",
	.version	= IPTABLES_VERSION,
	.size		= IPT_ALIGN(sizeof(struct ipt_antispoof_target_info)),
	.userspacesize	= IPT_ALIGN(sizeof(struct ipt_antispoof_target_info)),
	.help		= &help,
	.init		= &init,
	.parse		= &parse,
	.final_check	= &final_check,
	.print		= &print,
	.save		= &save,
	.extra_opts	= opts 
};

void _init(void)
{
	register_target(&ANTISPOOF);
}
